@@ -70,7 +70,7 @@ public class AlternateMixModule extends BaseTaskExecutionModule {
             .inputTypes(ModuleInputOutputType.MULTIPLE_PDF).name(DefaultI18nContext.getInstance().i18n("Alternate Mix"))
             .description(DefaultI18nContext.getInstance()
                     .i18n("Merge two or more PDF documents taking pages alternately in natural or reverse order."))
-            .priority(ModulePriority.DEFAULT.getPriority()).supportURL("http://www.pdfsam.org/mix-pdf/").build();
+            .priority(ModulePriority.DEFAULT.getPriority()).supportURL("https://pdfsam.org/mix-pdf/").build();
 
     @Inject
     public AlternateMixModule(@Named(MODULE_ID + "field") BrowsablePdfOutputField destinationFileField,
