@@ -112,6 +112,11 @@ public final class DefaultUserContext implements UserContext {
                 Boolean.valueOf(System.getProperty(CHECK_FOR_NEWS_PROP, Boolean.TRUE.toString())));
     }
 
+    @Override
+    public boolean isCompressionEnabled() {
+        return prefs.getBoolean(BooleanUserPreference.PDF_COMPRESSION_ENABLED.toString(), Boolean.TRUE);
+    }
+
     @Override
     public boolean isSavePwdInWorkspaceFile() {
         return prefs.getBoolean(BooleanUserPreference.SAVE_PWD_IN_WORKSPACE.toString(), Boolean.FALSE);
