@@ -41,7 +41,7 @@ public class FXValidationSupport<T> {
 
     private ReadOnlyObjectWrapper<ValidationState> validationState = new ReadOnlyObjectWrapper<>(
             ValidationState.NOT_VALIDATED);
-    private Validator<T> validator = new Validator<T>() {
+    private Validator<T> validator = new Validator<>() {
         @Override
         public boolean isValid(T input) {
             return true;
