@@ -21,23 +21,22 @@ package org.pdfsam.ui.io;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.hasProperty;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.argThat;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.verify;
+import static org.mockito.hamcrest.MockitoHamcrest.argThat;
 import static org.sejda.eventstudio.StaticStudio.eventStudio;
 
 import java.io.File;
 import java.io.IOException;
 import java.util.function.Consumer;
 
+import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
 import org.pdfsam.support.params.MultipleOutputTaskParametersBuilder;
 import org.pdfsam.test.HitTestListener;
 import org.pdfsam.test.InitializeAndApplyJavaFxThreadRule;
@@ -48,17 +47,20 @@ import org.sejda.model.parameter.base.MultipleOutputTaskParameters;
  * @author Andrea Vacondio
  *
  */
-@RunWith(MockitoJUnitRunner.class)
 public class BrowsableOutputDirectoryFieldTest {
     @Rule
     public TemporaryFolder folder = new TemporaryFolder();
     @Rule
     public InitializeAndApplyJavaFxThreadRule fxThread = new InitializeAndApplyJavaFxThreadRule();
-    @Mock
     private MultipleOutputTaskParametersBuilder<? extends MultipleOutputTaskParameters> builder;
-    @Mock
     private Consumer<String> onError;
 
+    @Before
+    public void setUp() {
+        onError = mock(Consumer.class);
+        builder = mock(MultipleOutputTaskParametersBuilder.class);
+    }
+
     @Test
     public void valid() throws IOException {
         BrowsableOutputDirectoryField victim = new BrowsableOutputDirectoryField();
