@@ -19,6 +19,7 @@
 package org.pdfsam.ui.selection.multiple;
 
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 import static org.sejda.eventstudio.StaticStudio.eventStudio;
 
 import java.io.File;
@@ -28,37 +29,40 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.junit.rules.TemporaryFolder;
-import org.loadui.testfx.GuiTest;
-import org.loadui.testfx.categories.TestFX;
-import org.loadui.testfx.exceptions.NoNodesFoundException;
-import org.loadui.testfx.utils.FXTestUtils;
+import org.pdfsam.NoHeadless;
 import org.pdfsam.i18n.DefaultI18nContext;
 import org.pdfsam.pdf.PdfDocumentDescriptor;
 import org.pdfsam.pdf.PdfLoadRequestEvent;
 import org.pdfsam.test.ClearEventStudioRule;
+import org.testfx.framework.junit.ApplicationTest;
+import org.testfx.matcher.control.TableViewMatchers;
+import org.testfx.util.WaitForAsyncUtils;
 
-import javafx.scene.Parent;
+import javafx.scene.Scene;
 import javafx.scene.input.KeyCode;
+import javafx.stage.Stage;
 
 /**
  * @author Andrea Vacondio
  *
  */
-@Category(TestFX.class)
-public class SelectionTableWithoutDuplicateTest extends GuiTest {
+public class SelectionTableWithoutDuplicateTest extends ApplicationTest {
     private static final String MODULE = "MODULE";
     @Rule
     public ClearEventStudioRule clearStudio = new ClearEventStudioRule(MODULE);
     @Rule
     public TemporaryFolder folder = new TemporaryFolder();
+    private SelectionTable victim;
 
     @Override
-    protected Parent getRootNode() {
-        SelectionTable victim = new SelectionTable(MODULE, false, true,
-                new SelectionTableColumn<?>[] { new LoadingColumn(MODULE), FileColumn.NAME, LongColumn.SIZE,
-                        IntColumn.PAGES, LongColumn.LAST_MODIFIED, new PageRangesColumn() });
+    public void start(Stage stage) throws Exception {
+        victim = new SelectionTable(MODULE, false, true, new SelectionTableColumn<?>[] { new LoadingColumn(MODULE),
+                FileColumn.NAME, LongColumn.SIZE, IntColumn.PAGES, LongColumn.LAST_MODIFIED, new PageRangesColumn() });
         victim.setId("victim");
-        return victim;
+        populate();
+        Scene scene = new Scene(victim);
+        stage.setScene(scene);
+        stage.show();
     }
 
     @After
@@ -66,11 +70,12 @@ public class SelectionTableWithoutDuplicateTest extends GuiTest {
         type(KeyCode.ESCAPE);
     }
 
-    @Test(expected = NoNodesFoundException.class)
-    public void duplicateIsMissing() throws Exception {
-        populate();
-        rightClick("temp.pdf");
-        assertFalse(exists(DefaultI18nContext.getInstance().i18n("Duplicate")));
+    @Test
+    @Category(NoHeadless.class)
+    public void duplicateIsMissing() {
+        rightClickOn(TableViewMatchers.hasTableCell("temp.pdf"));
+        assertFalse(lookup(DefaultI18nContext.getInstance().i18n("Duplicate")).tryQuery().isPresent());
+        assertTrue(lookup(DefaultI18nContext.getInstance().i18n("Set destination")).tryQuery().isPresent());
     }
 
     private PdfDocumentDescriptor populate() throws Exception {
@@ -78,9 +83,7 @@ public class SelectionTableWithoutDuplicateTest extends GuiTest {
         PdfLoadRequestEvent loadEvent = new PdfLoadRequestEvent(MODULE);
         PdfDocumentDescriptor ret = PdfDocumentDescriptor.newDescriptorNoPassword(file);
         loadEvent.add(ret);
-        FXTestUtils.invokeAndWait(() -> {
-            eventStudio().broadcast(loadEvent, MODULE);
-        } , 2);
+        WaitForAsyncUtils.waitForAsyncFx(2000, () -> eventStudio().broadcast(loadEvent, MODULE));
         return ret;
     }
 }
