@@ -19,49 +19,61 @@
 package org.pdfsam.ui.dashboard.modules;
 
 import static org.junit.Assert.assertEquals;
-import static org.loadui.testfx.Assertions.verifyThat;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.sejda.eventstudio.StaticStudio.eventStudio;
 
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.experimental.categories.Category;
-import org.loadui.testfx.GuiTest;
-import org.loadui.testfx.categories.TestFX;
 import org.mockito.ArgumentCaptor;
 import org.pdfsam.test.ClearEventStudioRule;
 import org.pdfsam.test.DefaultPriorityTestModule;
+import org.pdfsam.ui.commons.OpenUrlRequest;
 import org.pdfsam.ui.commons.SetActiveModuleRequest;
 import org.sejda.eventstudio.Listener;
+import org.testfx.api.FxAssert;
+import org.testfx.framework.junit.ApplicationTest;
 
-import javafx.scene.Parent;
+import de.jensd.fx.glyphs.materialdesignicons.MaterialDesignIcon;
+import javafx.scene.Scene;
 import javafx.scene.input.MouseButton;
+import javafx.stage.Stage;
 
 /**
  * @author Andrea Vacondio
  *
  */
-@Category(TestFX.class)
-public class ModulesDashboardTileTest extends GuiTest {
+public class ModulesDashboardTileTest extends ApplicationTest {
 
     @Rule
     public ClearEventStudioRule clearRule = new ClearEventStudioRule();
 
     @Override
-    protected Parent getRootNode() {
-        return new ModulesDashboardTile(new DefaultPriorityTestModule());
+    public void start(Stage stage) {
+        Scene scene = new Scene(new ModulesDashboardTile(new DefaultPriorityTestModule()));
+        stage.setScene(scene);
+        stage.show();
     }
 
     @Test
     public void activateOnClick() {
         Listener<SetActiveModuleRequest> listener = mock(Listener.class);
         eventStudio().add(SetActiveModuleRequest.class, listener);
-        move(".dashboard-modules-invisible-button").press(MouseButton.PRIMARY);
-        verifyThat(".dashboard-modules-tile", (ModulesDashboardTile v) -> v.isArmed());
+        moveTo(".dashboard-modules-invisible-button").press(MouseButton.PRIMARY);
+        FxAssert.verifyThat(".dashboard-modules-tile", (ModulesDashboardTile v) -> v.isArmed());
         release(MouseButton.PRIMARY);
         ArgumentCaptor<SetActiveModuleRequest> captor = ArgumentCaptor.forClass(SetActiveModuleRequest.class);
         verify(listener).onEvent(captor.capture());
         assertEquals(DefaultPriorityTestModule.ID, captor.getValue().getActiveModuleId().get());
     }
+
+    @Test
+    public void supportVideoClick() {
+        Listener<OpenUrlRequest> openUrlListener = mock(Listener.class);
+        eventStudio().add(OpenUrlRequest.class, openUrlListener);
+        ArgumentCaptor<OpenUrlRequest> openUrlCaptor = ArgumentCaptor.forClass(OpenUrlRequest.class);
+        clickOn(MaterialDesignIcon.HELP_CIRCLE.unicode());
+        verify(openUrlListener).onEvent(openUrlCaptor.capture());
+        assertEquals("http://www.chucknorrisfacts.com/", openUrlCaptor.getValue().getUrl());
+    }
 }
