@@ -18,6 +18,7 @@
  */
 package org.pdfsam.pdf;
 
+import static java.util.Objects.nonNull;
 import static org.sejda.eventstudio.StaticStudio.eventStudio;
 
 import java.util.HashMap;
@@ -29,6 +30,7 @@ import java.util.concurrent.Executors;
 import javax.inject.Inject;
 
 import org.pdfsam.ShutdownEvent;
+import org.pdfsam.i18n.DefaultI18nContext;
 import org.pdfsam.module.Module;
 import org.pdfsam.module.RequiredPdfData;
 import org.sejda.eventstudio.annotation.EventListener;
@@ -65,11 +67,39 @@ public class PdfLoadController {
      */
     @EventListener
     public void request(PdfLoadRequestEvent event) {
-        LOG.trace("Pdf load request received");
+        LOG.trace("PDF load request received");
         event.getDocuments().forEach(i -> i.moveStatusTo(PdfDescriptorLoadingStatus.REQUESTED));
         executor.execute(() -> loadService.load(event.getDocuments(), requiredLoadData.get(event.getOwnerModule())));
     }
 
+    /**
+     * Request to load a text/csv file containing a list of PDF
+     * 
+     * @param event
+     */
+    @EventListener
+    public void request(PdfFilesListLoadRequest event) {
+        LOG.trace("PDF load from list request received");
+        if (nonNull(event.list)) {
+            executor.execute(() -> {
+                try {
+                    PdfLoadRequestEvent loadEvent = new PdfLoadRequestEvent(event.getOwnerModule());
+                    new PdfListParser().apply(event.list).stream().map(PdfDocumentDescriptor::newDescriptorNoPassword)
+                            .forEach(loadEvent::add);
+                    if (loadEvent.getDocuments().isEmpty()) {
+                        LOG.error(DefaultI18nContext.getInstance()
+                                .i18n("Unable to find any valid PDF file in the list: {0}", event.list.toString()));
+                    } else {
+                        eventStudio().broadcast(loadEvent, event.getOwnerModule());
+                    }
+                } catch (Exception e) {
+                    LOG.error(DefaultI18nContext.getInstance().i18n("Unable to load PDF list file from {0}",
+                            event.list.toString()), e);
+                }
+            });
+        }
+    }
+
     @EventListener
     public void onShutdown(ShutdownEvent event) {
         executor.shutdownNow();
