@@ -19,6 +19,7 @@
 package org.pdfsam.premium;
 
 import static org.pdfsam.support.RequireUtils.requireNotNull;
+import static org.pdfsam.support.io.NetUtils.urlToStream;
 
 import java.io.IOException;
 import java.net.URL;
@@ -55,7 +56,7 @@ public class DefaultPremiumModulesService implements PremiumModulesService {
     public List<PremiumModule> getPremiumModules() {
         try {
             return JSON.std.with(Feature.READ_ONLY, true).listOfFrom(PremiumModule.class,
-                    new URL(pdfsam.property(ConfigurableProperty.PREMIUM_MODULES_URL)));
+                    urlToStream(new URL(pdfsam.property(ConfigurableProperty.PREMIUM_MODULES_URL))));
         } catch (IOException e) {
             LOG.warn(DefaultI18nContext.getInstance().i18n("Unable to retrieve premium features description"), e);
         }
