@@ -19,8 +19,10 @@
 package org.pdfsam.update;
 
 import static org.apache.commons.lang3.StringUtils.EMPTY;
+import static org.pdfsam.support.io.NetUtils.urlToStream;
 
 import java.io.IOException;
+import java.net.URL;
 
 import javax.inject.Inject;
 import javax.inject.Named;
@@ -51,6 +53,9 @@ class DefaultUpdateService implements UpdateService {
     @Override
     public String getLatestVersion() {
         try {
+            if (jsonSource instanceof URL) {
+                return JSON.std.mapFrom(urlToStream((URL) jsonSource)).getOrDefault(CURRENT_VERSION_KEY, "").toString();
+            }
             return JSON.std.mapFrom(jsonSource).getOrDefault(CURRENT_VERSION_KEY, "").toString();
         } catch (IOException e) {
             LOG.warn(DefaultI18nContext.getInstance().i18n("Unable to find the latest available version."), e);
